@@ -253,9 +253,18 @@ class CustomerOrderBatchHandler(BatchHandler):
         """
         batch.customer = None
         batch.person = None
-        batch.contact_name = None
-        batch.phone_number = None
-        batch.email_address = None
+
+        # note that if batch already has a "pending" customer on file,
+        # we will "restore" it as the contact info for the batch
+        pending = batch.pending_customer
+        if pending:
+            batch.contact_name = pending.display_name
+            batch.phone_number = pending.phone_number
+            batch.email_address = pending.email_address
+        else:
+            batch.contact_name = None
+            batch.phone_number = None
+            batch.email_address = None
 
         # always reset "add to customer" flags
         batch.clear_param('add_phone_number')
@@ -314,106 +323,25 @@ class CustomerOrderBatchHandler(BatchHandler):
         if cost:
             return cost.case_size
 
-    def get_phone_search_term(self, term):
-        """
-        Try to figure out if the given search term represents a whole
-        or partial phone number, and if so return just the digits.
-        """
-        digits = self.nondigits_pattern.sub('', term)
-        if digits and len(digits) >= 4:
-            return digits
-
+    # TODO: this method should maybe not exist?  and caller just
+    # invokes the handler directly instead?
     def customer_autocomplete(self, session, term, **kwargs):
         """
         Override the Customer autocomplete, to search by phone number
         as well as name.
         """
-        model = self.model
-
-        # define the base query
-        query = session.query(model.Customer)\
-                       .options(orm.joinedload(model.Customer.phones))
-
-        # does search term look like a phone number?
-        phone_term = self.get_phone_search_term(term)
-        if phone_term:
-
-            # yep, so just search for the phone number
-            query = query.join(model.CustomerPhoneNumber,
-                               model.CustomerPhoneNumber.parent_uuid == model.Customer.uuid)
-            query = query.filter(sa.func.regexp_replace(model.CustomerPhoneNumber.number,
-                                                        r'\D', '', 'g')\
-                                 .like('%{}%'.format(phone_term)))
-
-        else: # term does not look like a phone number
-
-            # so just search by name
-            criteria = [model.Customer.name.ilike('%{}%'.format(word))
-                        for word in term.split()]
-            query = query.filter(sa.and_(*criteria))
-
-        # oh, and sort by something useful
-        query = query.order_by(model.Customer.name)
-
-        # generate result list from query
-        results = []
-        for customer in query:
-            phone = customer.first_phone()
-            if phone:
-                label = "{} {}".format(customer.name, phone.number)
-            else:
-                label = customer.name
-            results.append({'value': customer.uuid,
-                            'label': label,
-                            'display': customer.name})
-
-        return results
+        autocompleter = self.app.get_autocompleter('customers.neworder')
+        return autocompleter.autocomplete(session, term, **kwargs)
 
+    # TODO: this method should maybe not exist?  and caller just
+    # invokes the handler directly instead?
     def person_autocomplete(self, session, term, **kwargs):
         """
         Override the Person autocomplete, to search by phone number as
         well as name.
         """
-        model = self.model
-
-        # define the base query
-        query = session.query(model.Person)\
-                       .options(orm.joinedload(model.Person.phones))
-
-        # does search term look like a phone number?
-        phone_term = self.get_phone_search_term(term)
-        if phone_term:
-
-            # yep, so just search for the phone number
-            query = query.join(model.PersonPhoneNumber,
-                               model.PersonPhoneNumber.parent_uuid == model.Person.uuid)
-            query = query.filter(sa.func.regexp_replace(model.PersonPhoneNumber.number,
-                                                        r'\D', '', 'g')\
-                                 .like('%{}%'.format(phone_term)))
-
-        else: # term does not look like a phone number
-
-            # so just search by name
-            criteria = [model.Person.display_name.ilike('%{}%'.format(word))
-                        for word in term.split()]
-            query = query.filter(sa.and_(*criteria))
-
-        # oh, and sort by something useful
-        query = query.order_by(model.Person.display_name)
-
-        # generate result list from query
-        results = []
-        for person in query:
-            phone = person.first_phone()
-            if phone:
-                label = "{} {}".format(person.display_name, phone.number)
-            else:
-                label = person.display_name
-            results.append({'value': person.uuid,
-                            'label': label,
-                            'display': person.display_name})
-
-        return results
+        autocompleter = self.app.get_autocompleter('people.neworder')
+        return autocompleter.autocomplete(session, term, **kwargs)
 
     def get_customer_info(self, batch, **kwargs):
         """
@@ -458,6 +386,33 @@ class CustomerOrderBatchHandler(BatchHandler):
                                   "{}.custom_product_autocomplete() "
                                   "method.".format(__class__.__name__))
 
+    def why_not_add_product(self, product, batch):
+        """
+        This method can inspect the given product, and batch, to
+        determine if the product may be added to the batch as a new
+        row.  Useful to e.g. prevent one customer from ordering too
+        many things, etc.
+
+        :returns: If there is a reason not to add the product, should
+           return that reason as a string; otherwise ``None``.
+        """
+
+    def add_product(self, batch, product, order_quantity, order_uom,
+                    **kwargs):
+        """
+        Add a new row to the batch, for the given product and order
+        quantity.
+        """
+        row = self.make_row()
+        row.item_entry = product.uuid
+        row.product = product
+        row.order_quantity = order_quantity
+        row.order_uom = order_uom
+        if 'price_needs_confirmation' in kwargs:
+            row.price_needs_confirmation = kwargs['price_needs_confirmation']
+        self.add_row(batch, row)
+        return row
+
     def refresh_row(self, row):
         if not row.product:
             if row.item_entry:
@@ -610,22 +565,22 @@ class CustomerOrderBatchHandler(BatchHandler):
             'unit_price',
             'discount_percent',
             'total_price',
+            'price_needs_confirmation',
             'paid_amount',
             'payment_transaction_number',
         ]
 
         def convert(row, i):
+
+            # add new order item
             item = model.CustomerOrderItem()
             item.sequence = i
-            item.status_code = self.enum.CUSTORDER_ITEM_STATUS_INITIATED
             for field in row_fields:
                 setattr(item, field, getattr(row, field))
             order.items.append(item)
 
-            # attach event
-            item.events.append(model.CustomerOrderItemEvent(
-                type_code=self.enum.CUSTORDER_ITEM_EVENT_INITIATED,
-                user=user))
+            # set initial status and attach events
+            self.set_initial_item_status(item, user)
 
         self.progress_loop(convert, batch.active_rows(), progress,
                            message="Converting batch rows to order items")
@@ -635,3 +590,35 @@ class CustomerOrderBatchHandler(BatchHandler):
         session.flush()
 
         return order
+
+    def set_initial_item_status(self, item, user, **kwargs):
+        """
+        Set the initial status for the given order item, and attach
+        any events.
+
+        The first logical status is ``CUSTORDER_ITEM_STATUS_INITIATED``
+        and an item may stay there if there is some other step(s)
+        which must occur before the item is ready to proceed.  For
+        instance the default logic will leave it there if the price
+        needs to be confirmed, but you can override as needed, for
+        instance if you require payment up-front.
+
+        The second status is ``CUSTORDER_ITEM_STATUS_READY`` which
+        indicates the item is ready to proceed.  The default logic
+        will auto-advance the item to this status if the price does
+        *not* need to be confirmed.  Again you may need to override
+        e.g. to prevent this until up-front payment is received.
+        """
+        # set "initiated" status
+        item.status_code = self.enum.CUSTORDER_ITEM_STATUS_INITIATED
+        item.add_event(self.enum.CUSTORDER_ITEM_EVENT_INITIATED, user)
+
+        # but if the price is good...
+        if not item.price_needs_confirmation:
+
+            # then we set "ready" status
+            item.status_code = self.enum.CUSTORDER_ITEM_STATUS_READY
+            item.status_text = "everything looks normal"
+
+            item.add_event(self.enum.CUSTORDER_ITEM_EVENT_READY, user,
+                           note=item.status_text)
