@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -169,6 +169,10 @@ class HandheldBatchHandler(BatchHandler):
         row.size = product.size
         row.status_code = row.STATUS_OK
 
+    def describe_execution(self, batch, **kwargs):
+        return ("A new batch will be created, using the items from this one.  "
+                "Type of the new batch depends on your choice of action.")
+
     def execute(self, batch, user=None, action='make_inventory_batch', progress=None, **kwargs):
         return self.execute_many([batch], user=user, action=action, progress=progress, **kwargs)
 
