@@ -552,6 +552,10 @@ class BatchHandler(object):
         if not entry:
             return
 
+        # if entry is a proper GPC then we kind of have only one thing to do
+        if isinstance(entry, GPC):
+            return api.get_product_by_upc(session, entry)
+
         # try to locate product by uuid before other, more specific key
         # if kwargs.get('try_uuid', True):
         product = session.query(model.Product).get(entry)
@@ -603,7 +607,14 @@ class BatchHandler(object):
 
         # if we made it this far, lookup by product key failed.
 
-        # okay then, let's maybe attempt lookup by "alternate" code
+        # try a vendor item code lookup, only if caller requests it
+        if kwargs.get('lookup_vendor_code'):
+            product = api.get_product_by_vendor_code(session, entry,
+                                                     vendor=kwargs.get('vendor'))
+            if product:
+                return product
+
+        # try an "alternate code" lookup, only if caller requests it
         if kwargs.get('lookup_by_code'):
             product = api.get_product_by_code(session, entry)
             if product:
