@@ -969,6 +969,43 @@ class FileMonitorCommand(Subcommand):
                 service.delayed_auto_start_service(name)
 
 
+class MailMonitorCommand(Subcommand):
+    """
+    Interacts with the mail monitor service; called as ``rattail
+    mailmon``.  This command expects a subcommand; one of the
+    following:
+
+    * ``rattail mailmon start``
+    * ``rattail mailmon stop``
+    """
+    name = 'mailmon'
+    description = "Manage the mail monitor daemon"
+
+    def add_parser_args(self, parser):
+        subparsers = parser.add_subparsers(title='subcommands')
+
+        start = subparsers.add_parser('start', help="Start service")
+        start.set_defaults(subcommand='start')
+
+        stop = subparsers.add_parser('stop', help="Stop service")
+        stop.set_defaults(subcommand='stop')
+
+        parser.add_argument('-p', '--pidfile', metavar='PATH', default='/var/run/rattail/mailmon.pid',
+                            help="Path to PID file.")
+
+    def run(self, args):
+        from rattail.mailmon.daemon import MailMonitorDaemon
+
+        daemon = MailMonitorDaemon(args.pidfile, config=self.config)
+        if args.subcommand == 'stop':
+            daemon.stop()
+        else: # start
+            try:
+                daemon.start(daemonize=False)
+            except KeyboardInterrupt:
+                self.stderr.write("Interrupted.\n")
+
+
 class LoadHostDataCommand(Subcommand):
     """
     Loads data from the Rattail host database, if one is configured.
