@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -79,6 +79,7 @@ class ImportSubcommand(Subcommand):
         if 'args' in kwargs:
             args = kwargs['args']
             kwargs.setdefault('dry_run', args.dry_run)
+            kwargs.setdefault('collect_changes_for_processing', args.collect_changes)
             if hasattr(args, 'batch_size'):
                 kwargs.setdefault('batch_size', args.batch_size)
             if args.max_diffs:
@@ -168,6 +169,18 @@ class ImportSubcommand(Subcommand):
                             "given import task should stop.  Note that this applies on a per-model "
                             "basis and not overall.")
 
+        # collect changes for processing
+        parser.add_argument('--collect-changes', action='store_true', default=True,
+                            help="Collect changes along the way, for processing "
+                            "at the end of the run.  This is on by default as it "
+                            "is required for reporting how many changes occurred, "
+                            "as well as being used for diff warning emails.")
+        parser.add_argument('--no-collect-changes', action='store_false', dest='collect_changes',
+                            help="Do *not* collect changes for processing at the "
+                            "end of the run.  The main reason for this flag is to "
+                            "cut down on memory usage during the run, but it will "
+                            "cause the final tally reporting not to work.")
+
         # max total changes, per model
         parser.add_argument('--max-total', type=int, metavar='COUNT',
                             help="Maximum number of *any* record changes which may occur, after which "
