@@ -38,7 +38,7 @@ import logging.config
 
 import six
 
-from rattail.util import load_entry_points, import_module_path
+from rattail.util import load_entry_points, import_module_path, load_object
 from rattail.exceptions import WindowsExtensionsNotInstalled, ConfigurationError
 from rattail.files import temp_path
 from rattail.logging import TimeConverter
@@ -837,6 +837,30 @@ class ConfigProfile(object):
     def __init__(self, config, key, **kwargs):
         self.config = config
         self.key = key
+        self.load()
+
+    def load(self):
+        """
+        Read all relevant settings etc. from the config object,
+        setting attributes on this profile instance as needed.
+        """
+
+    def load_defaults(self):
+        """
+        Read all "default" (common) settings from config, for the
+        current profile.
+        """
+        self.workdir = self._config_string('workdir')
+        self.stop_on_error = self._config_boolean('stop_on_error', False)
+
+    def load_actions(self):
+        """
+        Read the "actions" from config, for the current profile, and
+        assign the result to ``self.actions``.
+        """
+        self.actions = []
+        for action in self._config_list('actions'):
+            self.actions.append(self._config_action(action))
 
     @property
     def section(self):
@@ -881,6 +905,99 @@ class ConfigProfile(object):
     def _config_list(self, option):
         return parse_list(self._config_string(option))
 
+    def _config_action(self, name):
+        """
+        Retrieve an "action" value from config, for the current
+        profile.  This returns a :class:`ConfigProfileAction`
+        instance.
+        """
+        from rattail.monitoring import CommandAction
+
+        function = self._config_string('action.{}.func'.format(name))
+        class_ = self._config_string('action.{}.class'.format(name))
+        cmd = self._config_string('action.{}.cmd'.format(name))
+
+        specs = [1 if spec else 0 for spec in (function, class_, cmd)]
+        if sum(specs) != 1:
+            raise ConfigurationError(
+                "Monitor profile '{}' (action '{}') must have exactly one of: "
+                "function, class, command".format(self.key, name))
+
+        action = ConfigProfileAction()
+        action.config = self.config
+
+        if function:
+            action.spec = function
+            action.action = load_object(action.spec)
+        elif class_:
+            action.spec = class_
+            action.action = load_object(action.spec)(self.config)
+        elif cmd:
+            action.spec = cmd
+            action.action = CommandAction(self.config, cmd)
+
+        action.args = self._config_list('action.{}.args'.format(name))
+
+        action.kwargs = {}
+        pattern = re.compile(r'^{}\.action\.{}\.kwarg\.(?P<keyword>\w+)$'.format(self.key, name), re.IGNORECASE)
+
+        # TODO: this should not be referencing the config parser directly!
+        # (but we have no other way yet, to know which options are defined)
+        # (we should at least allow config to be defined in DB Settings)
+        # (however that should be optional, since some may not have a DB)
+        for option in self.config.parser.options(self.section):
+            match = pattern.match(option)
+            if match:
+                action.kwargs[match.group('keyword')] = self.config.get(self.section, option)
+
+        action.retry_attempts = self._config_int('action.{}.retry_attempts'.format(name), minimum=1)
+        action.retry_delay = self._config_int('action.{}.retry_delay'.format(name), minimum=0)
+        return action
+
+
+class ConfigProfileAction(object):
+    """
+    Simple class to hold configuration for a particular "action"
+    defined within a monitor :class:`ConfigProfile`.  Each instance
+    has the following attributes:
+
+    .. attribute:: spec
+
+       The original "spec" string used to obtain the action callable.
+
+    .. attribute:: action
+
+       A reference to the action callable.
+
+    .. attribute:: args
+
+       A sequence of positional arguments to be passed to the callable
+       (in addition to the file path) when invoking the action.
+
+    .. attribute:: kwargs
+
+       A dictionary of keyword arguments to be passed to the callable
+       (in addition to the positional arguments) when invoking the
+       action.
+
+    .. attribute:: retry_attempts
+
+       Number of attempts to make when invoking the action.  Defaults
+       to ``1``, meaning the first attempt will be made but no retries
+       will happen.
+
+    .. attribute:: retry_delay
+
+       Number of seconds to pause between retry attempts, if
+       :attr:`retry_attempts` is greater than one.  Defaults to ``0``.
+    """
+    spec = None
+    action = None
+    args = []
+    kwargs = {}
+    retry_attempts = 1
+    retry_delay = 0
+
 
 class FreeTDSLoggingFilter(logging.Filter):
     """
