@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -27,5 +27,5 @@ DataSync Daemon
 from __future__ import unicode_literals, absolute_import
 
 from .watchers import DataSyncWatcher
-from .consumers import DataSyncConsumer, NewDataSyncImportConsumer
+from .consumers import DataSyncConsumer, NewDataSyncImportConsumer, FromRattailConsumer
 from .rattail import FromRattailToRattailExportConsumer, FromRattailToRattailImportConsumer
