@@ -69,6 +69,10 @@ class Department(Base):
        Stamps, Lottery Tickets, etc.).
     """)
 
+    allow_product_deletions = sa.Column(sa.Boolean(), nullable=True, doc="""
+    Whether products belonging to this department may be deleted.
+    """)
+
     def __str__(self):
         return self.name or ''
 
