@@ -146,6 +146,44 @@ class filemon_action_error(Email):
         }
 
 
+class new_email_requested(Email):
+    """
+    Sent when a new email address is requested for a customer,
+    e.g. when entering a new customer order.
+    """
+    default_subject = "Email Update Request"
+
+    def sample_data(self, request):
+        model = request.rattail_config.get_model()
+        customer = model.Customer(name="Fred Flintstone")
+        return {
+            'user': request.user,
+            'user_display': request.user.display_name,
+            'contact': customer,
+            'contact_id': '42',
+            'email_address': "fred@mailinator.com",
+        }
+
+
+class new_phone_requested(Email):
+    """
+    Sent when a new phone number is requested for a customer,
+    e.g. when entering a new customer order.
+    """
+    default_subject = "Phone Update Request"
+
+    def sample_data(self, request):
+        model = request.rattail_config.get_model()
+        customer = model.Customer(name="Fred Flintstone")
+        return {
+            'user': request.user,
+            'user_display': request.user.display_name,
+            'contact': customer,
+            'contact_id': '42',
+            'phone_number': "417-555-1234",
+        }
+
+
 class ImporterEmail(Email):
     """
     Sent when a "version catch-up" import is performed, which involves changes.
