@@ -95,7 +95,9 @@ CUSTORDER_STATUS = {
 CUSTORDER_ITEM_STATUS_INITIATED         = 10
 # TODO: deprecate / remove this one
 CUSTORDER_ITEM_STATUS_ORDERED           = CUSTORDER_ITEM_STATUS_INITIATED
-CUSTORDER_ITEM_STATUS_PAID              = 20
+CUSTORDER_ITEM_STATUS_READY             = 20
+# TODO: deprecate / remove this one
+CUSTORDER_ITEM_STATUS_PAID              = CUSTORDER_ITEM_STATUS_READY
 CUSTORDER_ITEM_STATUS_PLACED            = 30
 CUSTORDER_ITEM_STATUS_RECEIVED          = 40
 CUSTORDER_ITEM_STATUS_CONTACTED         = 50
@@ -110,7 +112,8 @@ CUSTORDER_ITEM_STATUS_INACTIVE          = 950
 
 CUSTORDER_ITEM_STATUS = OrderedDict([
     (CUSTORDER_ITEM_STATUS_INITIATED,           "customer order initiated"),
-    (CUSTORDER_ITEM_STATUS_PAID,                "payment received"),
+    # (CUSTORDER_ITEM_STATUS_PAID,                "payment received"),
+    (CUSTORDER_ITEM_STATUS_READY,               "ready to proceed"),
     (CUSTORDER_ITEM_STATUS_PLACED,              "order placed with vendor"),
     (CUSTORDER_ITEM_STATUS_RECEIVED,            "received from vendor"),
     (CUSTORDER_ITEM_STATUS_CONTACTED,           "customer contacted"),
@@ -126,7 +129,10 @@ CUSTORDER_ITEM_STATUS = OrderedDict([
 
 
 CUSTORDER_ITEM_EVENT_INITIATED          = 10
-CUSTORDER_ITEM_EVENT_PAID               = 20
+CUSTORDER_ITEM_EVENT_PRICE_CONFIRMED    = 15
+CUSTORDER_ITEM_EVENT_READY              = 20
+# TODO: deprecate / remove this one
+CUSTORDER_ITEM_EVENT_PAID               = CUSTORDER_ITEM_EVENT_READY
 CUSTORDER_ITEM_EVENT_PLACED             = 30
 CUSTORDER_ITEM_EVENT_RECEIVED           = 40
 CUSTORDER_ITEM_EVENT_CONTACTED          = 50
@@ -143,7 +149,9 @@ CUSTORDER_ITEM_EVENT_INACTIVE           = 950
 
 CUSTORDER_ITEM_EVENT = OrderedDict([
     (CUSTORDER_ITEM_EVENT_INITIATED,            "customer order initiated"),
-    (CUSTORDER_ITEM_EVENT_PAID,                 "payment received"),
+    (CUSTORDER_ITEM_EVENT_PRICE_CONFIRMED,      "price confirmed"),
+    (CUSTORDER_ITEM_EVENT_READY,                "order becomes ready to proceed"),
+    # (CUSTORDER_ITEM_EVENT_PAID,                 "payment received"),
     (CUSTORDER_ITEM_EVENT_PLACED,               "order placed with vendor"),
     (CUSTORDER_ITEM_EVENT_RECEIVED,             "received from vendor"),
     (CUSTORDER_ITEM_EVENT_CONTACTED,            "customer contacted"),
