@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,9 +24,9 @@
 File Monitor for Linux
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
-import Queue
+from six.moves import queue
 import logging
 
 import pyinotify
@@ -97,10 +97,10 @@ class FileMonitorDaemon(Daemon):
                 | pyinotify.IN_MOVED_TO)
 
         monitored = load_profiles(self.config)
-        for key, profile in monitored.iteritems():
+        for key, profile in monitored.items():
 
             # Create a file queue for the profile.
-            profile.queue = Queue.Queue()
+            profile.queue = queue.Queue()
 
             # Perform setup for each of the watched folders.
             for path in profile.dirs:
