@@ -89,6 +89,7 @@ class ImportHandler(object):
     commit_host_partial = False
     diff_max_display = 15
     direction = 'import'
+    collect_changes_for_processing = True
 
     def __init__(self, config=None, **kwargs):
         self.config = config
@@ -131,6 +132,7 @@ class ImportHandler(object):
             kwargs.setdefault('config', self.config)
             kwargs.setdefault('host_system_title', self.host_title)
             kwargs.setdefault('direction', self.direction)
+            kwargs.setdefault('collect_changes_for_processing', self.collect_changes_for_processing)
             if hasattr(self, 'batch_size'):
                 kwargs.setdefault('batch_size', self.batch_size)
             if hasattr(self, 'runas_username') and self.runas_username:
