@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
@@ -24,7 +24,7 @@
 Logging Utilities
 """
 
-from __future__ import absolute_import
+from __future__ import unicode_literals, absolute_import
 
 import os
 import sys
@@ -102,3 +102,17 @@ class TimeConverter(object):
         value = pytz.utc.localize(value)
         value = localtime(self.config, value)
         return value.timetuple()
+
+
+class LuigiSummaryFilter(logging.Filter):
+    """
+    Custom logging filter, to elevate the Luigi "execution summary" message to
+    WARNING level, so that it shows up even when we ignore INFO logging.
+    """
+
+    def filter(self, record):
+        if record.name == 'luigi-interface' and record.levelno == logging.INFO:
+            if "===== Luigi Execution Summary =====" in record.msg:
+                record.levelno = logging.WARNING
+                record.levelname = 'WARNING'
+        return True
