@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -64,8 +64,8 @@ def send_email(config, key, data={}, attachments=[],
     Send an email message of the given type, per config, with the given data
     and/or attachments.
     """
-    # TODO: should let config override which handler we use
-    handler = EmailHandler(config)
+    app = config.get_app()
+    handler = app.get_email_handler()
     email = handler.get_email(key, fallback_key=fallback_key,
                               default_subject=default_subject)
 
@@ -272,6 +272,14 @@ class EmailHandler(object):
         return False
 
 
+def get_email_handler(config):
+    """
+    Creates and returns the configured mail handler.
+    """
+    # TODO: should let config override which handler we use
+    return EmailHandler(config)
+
+
 class Email(object):
     # Note: The docstring of an email is leveraged by code, hence this odd one.
     """
