@@ -314,6 +314,7 @@ class PeopleHandler(GenericHandler):
             F('last_name'),
             F('display_name'),
             F('usernames', additive=True),
+            F('employee_uuid', coalesce=True),
             F('member_uuids', additive=True),
         ]
 
@@ -328,6 +329,7 @@ class PeopleHandler(GenericHandler):
             'last_name': person.last_name,
             'display_name': person.display_name,
             'usernames': [u.username for u in person.users],
+            'employee_uuid': person.employee.uuid if person.employee else None,
             'member_uuids': [m.uuid for m in person.members],
         }
 
@@ -379,6 +381,9 @@ class PeopleHandler(GenericHandler):
            merge happen.
         :returns: String indicating reason not to merge, or ``None``.
         """
+        if removing.employee and keeping.employee:
+            if removing.employee is not keeping.employee:
+                return "Cannot merge 2 people who are distinct employees"
 
     def perform_merge(self, removing, keeping, **kwargs):
         """
@@ -392,6 +397,14 @@ class PeopleHandler(GenericHandler):
             removing.members.remove(member)
             keeping.members.append(member)
 
+        # move Employee record to final Person
+        if removing.employee:
+            if keeping.employee and keeping.employee is not removing.employee:
+                raise RuntimeError("Cannot merge 2 people who are distinct employees")
+            if not keeping.employee:
+                employee = removing.employee
+                employee.person = keeping
+
         # move User records to final Person
         for user in list(removing.users):
             removing.users.remove(user)
