@@ -127,6 +127,28 @@ class rattail_custorders_new_order_requires_customer(Setting):
     name = 'new_order_requires_customer'
     data_type = bool
 
+class rattail_custorders_new_orders_allow_contact_info_choice(Setting):
+    """
+    If set, then user can choose from contact info options, when
+    creating new order.  If *not* set then they cannot choose, and
+    must use whatever the batch handler provides.
+    """
+    group = "Customer Orders"
+    namespace = 'rattail.custorders'
+    name = 'new_orders.allow_contact_info_choice'
+    data_type = bool
+
+class rattail_custorders_new_orders_restrict_contact_info(Setting):
+    """
+    If set, then user can only choose from existing contact info options,
+    for the customer/order.  If *not* set, then user is allowed to enter
+    new/different contact info.
+    """
+    group = "Customer Orders"
+    namespace = 'rattail.custorders'
+    name = 'new_orders.restrict_contact_info'
+    data_type = bool
+
 
 ##############################
 # DataSync
