@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -29,12 +29,16 @@ from __future__ import unicode_literals, absolute_import
 import os
 import shutil
 import subprocess
+import logging
 
 from rattail.time import make_utc
 from rattail.util import load_object
 from rattail.mail import send_email
 
 
+log = logging.getLogger(__name__)
+
+
 class UpgradeHandler(object):
     """
     Base class and default implementation for upgrade handlers.
@@ -86,10 +90,14 @@ class UpgradeHandler(object):
         stdout_path = self.config.upgrade_filepath(upgrade.uuid, filename='stdout.log')
         stderr_path = self.config.upgrade_filepath(upgrade.uuid, filename='stderr.log')
         cmd = self.config.upgrade_command()
+        log.debug("will run upgrade command: %s", cmd)
         with open(stdout_path, 'wb') as stdout:
             with open(stderr_path, 'wb') as stderr:
                 upgrade.exit_code = subprocess.call(cmd, stdout=stdout, stderr=stderr)
 
+        logger = log.warning if upgrade.exit_code != 0 else log.debug
+        logger("upgrade command exit code was: %s", upgrade.exit_code)
+
         after_path = self.config.upgrade_filepath(upgrade.uuid, filename='requirements.after.txt')
         self.record_requirements_snapshot(after_path)
         return upgrade.exit_code == 0
