@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -49,6 +49,8 @@ class CatalogParser(object):
     """
     vendor_key = None
 
+    # TODO: should add constructor, to accept `config` kwarg at least
+
     @property
     def key(self):
         """
@@ -75,8 +77,11 @@ class CatalogParser(object):
             return None
 
         # No reason to convert integers, really.
-        if isinstance(value, (Decimal, int, long)):
+        if isinstance(value, six.integer_types):
             return value
+        if isinstance(value, Decimal):
+            return value
+
         if isinstance(value, float):
             value = "{{0:0.{0}f}}".format(scale).format(value)
         else:
